@@ -1,20 +1,25 @@
-# @(#)$Ident: Cache.pm 2013-09-13 18:10 pjf ;
+# @(#)$Ident: Cache.pm 2013-12-31 14:33 pjf ;
 
 package File::DataClass::Cache;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.27.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.28.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
+use Moo;
 use File::DataClass::Constants;
 use File::DataClass::Functions qw( merge_attributes throw );
 use File::DataClass::Types     qw( Bool Cache ClassName HashRef
                                    LoadableClass Object Str );
-use Moo;
 
-has 'cache'            => is => 'lazy', isa => Object;
+has 'cache'            => is => 'lazy', isa => Object, builder => sub {
+   my $self = shift; my $attr = $self->cache_attributes; my $log = $self->log;
 
-has 'cache_attributes' => is => 'ro',   isa => HashRef,
-   default             => sub { {} };
+   $attr->{on_set_error} = sub { $log->error( $_[ 0 ] ) };
+
+   return $self->cache_class->new( %{ $attr } );
+};
+
+has 'cache_attributes' => is => 'ro',   isa => HashRef, default => sub { {} };
 
 has 'cache_class'      => is => 'lazy', isa => LoadableClass, default => 'CHI';
 
@@ -71,6 +76,7 @@ sub remove {
    my ($self, $key) = @_; $key or return; $key .= NUL;
 
    $self->cache->remove( $key ); $self->set_mtime( $key, undef );
+
    return;
 }
 
@@ -79,7 +85,7 @@ sub set {
 
    $key .= NUL; $meta ||= {}; $meta->{mtime} //= undef;
 
-   $key eq $mt_key and throw error => 'Cache key "[_1]" not allowed',
+   $key eq $mt_key and throw error => 'Cache key [_1] not allowed',
                              args  => [ $mt_key ];
 
    if ($key and defined $data) {
@@ -95,7 +101,8 @@ sub set_by_paths {
 
    my ($key, $newest) = $self->_get_key_and_newest( $paths );
 
-   $meta->{mtime} = $newest; return $self->set( $key, $data, $meta );
+   $meta->{mtime} = $newest;
+   return $self->set( $key, $data, $meta );
 }
 
 sub set_mtime {
@@ -110,14 +117,6 @@ sub set_mtime {
 }
 
 # Private methods
-sub _build_cache {
-   my $self = shift; my $attr = $self->cache_attributes; my $log = $self->log;
-
-   $attr->{on_set_error} = sub { $log->error( $_[ 0 ] ) };
-
-   return $self->cache_class->new( %{ $attr } );
-}
-
 sub _get_key_and_newest {
    my ($self, $paths) = @_; my $newest = 0; my $valid = TRUE;  my $key;
 
@@ -143,7 +142,7 @@ File::DataClass::Cache - Adds extra methods to the CHI API
 
 =head1 Version
 
-This document describes version v0.27.$Rev: 1 $
+This document describes version v0.28.$Rev: 1 $
 
 =head1 Synopsis
 
@@ -300,7 +299,7 @@ Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2014 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
