@@ -1,12 +1,13 @@
-# @(#)$Ident: IO.pm 2013-09-30 16:49 pjf ;
+# @(#)$Ident: IO.pm 2014-01-01 00:48 pjf ;
 
 package File::DataClass::IO;
 
 use 5.010001;
 use namespace::clean -except => 'meta';
 use overload '""' => sub { shift->pathname }, fallback => 1;
-use version; our $VERSION = qv( sprintf '0.27.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.28.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
+use Moo;
 use English                    qw( -no_match_vars );
 use Exporter 5.57              qw( import );
 use Fcntl                      qw( :flock :seek );
@@ -21,9 +22,9 @@ use File::Temp                   ( );
 use IO::Dir;
 use IO::File;
 use List::Util                 qw( first );
-use Moo;
 use Scalar::Util               qw( blessed );
 use Type::Utils                qw( enum );
+use Unexpected::Functions      qw( NotFound Unspecified );
 use Unexpected::Types          qw( ArrayRef Bool CodeRef Int Maybe Object
                                    PositiveInt RegexpRef SimpleStr Str );
 
@@ -151,11 +152,11 @@ sub all_files {
 sub _all_file_contents {
    my $self = shift; $self->is_open or $self->assert_open;
 
-   local $RS = undef; my $all = $self->io_handle->getline;
+   local $RS = undef; my $content = $self->io_handle->getline;
 
    $self->error_check; $self->autoclose and $self->close;
 
-   return $all;
+   return $content;
 }
 
 sub append {
@@ -200,7 +201,7 @@ sub assert_dirpath {
 sub assert_filepath {
    my $self = shift; my $dir;
 
-   $self->name or $self->_throw( 'Path not specified' );
+   $self->name or $self->_throw( class => Unspecified, args => [ 'Path name' ]);
 
    (undef, $dir) = File::Spec->splitpath( $self->name );
 
@@ -271,11 +272,13 @@ sub buffer {
 }
 
 sub _build__dir_pattern {
-   my $self = shift; my ($curdir, $pat, $updir);
+   my $self = shift; my $pat = NUL;
 
-   $pat  = "\Q$curdir\E" if ($curdir = File::Spec->curdir);
-   $pat .= '|'           if ($updir  = File::Spec->updir and $pat);
-   $pat .= "\Q$updir\E"  if ($updir);
+   my $curdir = File::Spec->curdir; my $updir = File::Spec->updir;
+
+   $curdir and $pat  = "\Q${curdir}\E"; # uncoverable condition left
+   $curdir and $updir and $pat .= '|';  # uncoverable condition left
+   $updir  and $pat .= "\Q${updir}\E";  # uncoverable condition left
 
    return qr{ \A $pat \z }mx;
 }
@@ -301,8 +304,9 @@ sub catfile {
 }
 
 sub chmod {
-   my ($self, $perms) = @_; $perms ||= $self->_perms;
+   my ($self, $perms) = @_;
 
+   $perms ||= $self->_perms; # uncoverable condition false
    CORE::chmod $perms, $self->name;
    return $self;
 }
@@ -314,8 +318,12 @@ sub chomp {
 sub chown {
    my ($self, $uid, $gid) = @_;
 
-   defined $uid and defined $gid and CORE::chown $uid, $gid, $self->name;
+   (defined $uid and defined $gid)
+      or $self->_throw( class => Unspecified, args => [ 'User or group id' ] );
 
+   1 == CORE::chown $uid, $gid, $self->name
+      or $self->_throw( error => 'Path [_1 chown failed to [_2]/[_3]',
+                        args  => [ $self->name, $uid, $gid ] );
    return $self;
 }
 
@@ -335,7 +343,10 @@ sub close {
 }
 
 sub _close_and_rename { # This creates a race condition
-   my $self = shift; my $handle; $self->unlock;
+   # uncoverable subroutine
+   my $self = shift; # uncoverable statement
+
+   my $handle; $self->unlock;
 
    if ($handle = $self->io_handle) { $handle->close; delete $self->{io_handle} }
 
@@ -359,7 +370,9 @@ sub _constructor {
 }
 
 sub copy {
-   my ($self, $to) = @_; $to or $self->_throw( 'Copy requires two args' );
+   my ($self, $to) = @_;
+
+   $to or $self->_throw( class => Unspecified, args => [ 'Copy to' ] );
 
    (blessed $to and $to->isa( __PACKAGE__ ))
       or $to = $self->_constructor( $to );
@@ -388,9 +401,9 @@ sub delete {
 }
 
 sub delete_tmp_files {
-   my ($self, $tmplt) = @_;
+   my ($self, $tmplt) = @_; $tmplt ||= '%6.6d....';
 
-   $tmplt ||= '%6.6d....'; my $pat = sprintf $tmplt, $PID;
+   my $pat = sprintf $tmplt, $PID;
 
    while (my $entry = $self->next) {
       $entry->filename =~ m{ \A $pat \z }mx and unlink $entry->pathname;
@@ -412,11 +425,9 @@ sub dirname {
 }
 
 sub empty {
-   my $self = shift;
+   my $self = shift; $self->is_file and return -z $self->name;
 
-   $self->is_file and return -z $self->name;
-   $self->is_dir  or  $self->_throw( error => 'Path [_1] not found',
-                                     args  => [ $self->name ] );
+   $self->is_dir or $self->_throw( class => NotFound, args => [ $self->name ] );
 
    return $self->next ? FALSE : TRUE;
 }
@@ -424,12 +435,12 @@ sub empty {
 sub encoding {
    my ($self, $encoding) = @_;
 
-   $encoding and lc $encoding eq 'utf-8' and $encoding = 'utf8';
-   $encoding or
-      $self->_throw( 'No encoding value passed to '.__PACKAGE__.'::encoding' );
-   $self->is_open and CORE::binmode( $self->io_handle, ":encoding($encoding)" );
+   $encoding or $self->_throw
+      ( class => Unspecified, args => [ 'Encoding value' ] );
+   lc $encoding eq 'utf-8' and $encoding = 'utf8';
    $self->_encoding( $encoding );
    $self->_set_is_utf8( $encoding eq 'utf8' ? TRUE : FALSE );
+   $self->is_open and $self->set_binmode;
    return $self;
 }
 
@@ -438,7 +449,7 @@ sub error_check {
 
    $self->io_handle->can( 'error' ) or return;
    $self->io_handle->error or return;
-   $self->_throw( error => 'IO error [_1]', args => [ $OS_ERROR ] );
+   $self->_throw( error => 'IO error: [_1]', args => [ $OS_ERROR ] );
    return;
 }
 
@@ -508,7 +519,7 @@ sub _get_atomic_path {
 sub getline {
    my ($self, $separator) = @_; my $line; $self->assert_open;
 
-   {  local $RS = $separator || $self->_separator;
+   {  local $RS = $separator // $self->_separator; # uncoverable condition false
       $line = $self->io_handle->getline;
       defined $line and $self->_chomp and CORE::chomp $line;
    }
@@ -522,7 +533,7 @@ sub getline {
 sub getlines {
    my ($self, $separator) = @_; my @lines; $self->assert_open;
 
-   {  local $RS = $separator || $self->_separator;
+   {  local $RS = $separator // $self->_separator; # uncoverable condition false
       @lines = $self->io_handle->getlines;
 
       if ($self->_chomp) { CORE::chomp for @lines }
@@ -563,7 +574,7 @@ sub is_dir {
 
    $self->type or $self->_init_type_from_fs or return FALSE;
 
-   return $self->type && $self->type eq 'dir' ? TRUE : FALSE;
+   return $self->type eq 'dir' ? TRUE : FALSE;
 }
 
 sub is_executable {
@@ -663,7 +674,6 @@ sub next {
    my $io = $self->_constructor( [ $self->name, $name ] );
 
    defined $self->_filter and $io->filter( $self->_filter );
-
    return $io;
 }
 
@@ -693,7 +703,7 @@ sub open {
 sub _open_args {
    my ($self, $mode, $perms) = @_;
 
-   $self->name or $self->_throw( 'Path not specified' );
+   $self->name or $self->_throw( class => Unspecified, args => [ 'Path name' ]);
 
    my $pathname = $self->_atomic && !$self->is_reading( $mode )
                 ? $self->_get_atomic_path : $self->name;
@@ -725,7 +735,7 @@ sub _open_file {
    }
 
    $self->_umask_pop;
-   CORE::chmod $perms, $path; # Not necessary on normal systems
+   CORE::chmod $perms, $path; # TODO: Not necessary on normal systems
    $self->_set_is_open( TRUE );
    $self->set_binmode;
    $self->set_lock;
@@ -757,7 +767,7 @@ sub _print {
 
    for (@args) {
       print {$self->io_handle} $_
-         or $self->_throw( error => 'IO error [_1]', args  => [ $OS_ERROR ] );
+         or $self->_throw( error => 'IO error: [_1]', args  => [ $OS_ERROR ] );
    }
 
    return $self;
@@ -861,7 +871,6 @@ sub seek {
    $self->is_open or $self->assert_open( $LC_OSNAME eq EVIL ? 'r' : 'r+' );
 
    $self->io_handle->seek( @args ); $self->error_check;
-
    return $self;
 }
 
@@ -891,7 +900,6 @@ sub set_lock {
    $self->_lock_obj and return $self->_lock_obj->set( k => $self->name );
 
    flock $self->io_handle, $self->mode eq 'r' ? LOCK_SH : LOCK_EX;
-
    return $self;
 }
 
@@ -932,7 +940,8 @@ sub substitute {
 
    for ($self->getlines) { s{ $search }{$replace}gmx; $wtr->print( $_ ) }
 
-   $self->close; $wtr->close; return $self;
+   $self->close; $wtr->close;
+   return $self;
 }
 
 sub tempfile {
@@ -943,11 +952,13 @@ sub tempfile {
    $tmplt ||= '%6.6dXXXX';
    $tmpfh   = File::Temp->new
       ( DIR => $tempdir, TEMPLATE => (sprintf $tmplt, $PID) );
-   $self->_init( 'file', $tmpfh->filename );
-   $self->_set_io_handle( $tmpfh );
-   $self->_set_is_open( TRUE );
-   $self->_set_mode( 'w+' );
-   return $self;
+
+   my $t = $self->_constructor( $tmpfh->filename )->file;
+
+   $t->_set_io_handle( $tmpfh );
+   $t->_set_is_open( TRUE );
+   $t->_set_mode( 'w+' );
+   return $t;
 }
 
 sub _throw {
@@ -970,7 +981,8 @@ sub _umask_pop {
 
    (defined $perms and $perms != NO_UMASK_STACK) or return umask;
 
-   umask pop @{ $self->_umask }; return $perms;
+   umask pop @{ $self->_umask };
+   return $perms;
 }
 
 sub _umask_push {
@@ -1036,7 +1048,7 @@ File::DataClass::IO - Better IO syntax
 
 =head1 Version
 
-This document describes version v0.27.$Rev: 1 $
+This document describes version v0.28.$Rev: 1 $ of L<File::DataClass::IO>
 
 =head1 Synopsis
 
@@ -1151,9 +1163,10 @@ An object which is a L<File::DataClass::IO>
 
 =head2 abs2rel
 
-   $path = io( 'relative_path_to_file' )->abs2rel( 'optional_base_path' );
+   $path = io( 'path_to_file' )->abs2rel( 'optional_base_path' );
 
-Makes the pathname relative. Returns a path
+Makes the pathname relative via a call to
+L<abs2rel|File::Spec/abs2rel>. Returns a path
 
 =head2 absolute
 
@@ -1827,9 +1840,9 @@ address below. Patches are welcome
 
 For the Perl programming language
 
-=item Ingy dt Net <ingy@cpan.org>
+=item Ingy döt Net <ingy@cpan.org>
 
-For IO::All from which I took the API and some tests
+For L<IO::All> from which I took the API and some tests
 
 =item L<Path::Tiny>
 
@@ -1840,11 +1853,11 @@ file name, not following symlinks and some tests
 
 =head1 Author
 
-Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
+Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2014 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
@@ -1856,6 +1869,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE
 =cut
 
 # Local Variables:
+# coding: utf-8
 # mode: perl
 # tab-width: 3
 # End:
